<?php
/*
# ------------------------------------------------------------------------
# JA Compress plugin for Joomla 1.5
# ------------------------------------------------------------------------
# Copyright (C) 2004-2010 JoomlArt.com. All Rights Reserved.
# @license GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
# Author: JoomlArt.com
# Websites: http://www.joomlart.com - http://www.joomlancers.com.
# ------------------------------------------------------------------------
*/

defined( '_JEXEC' ) or die();

// Import system file
jimport('joomla.cache.cache');
// jimport('joomla.cache.handler.page');
require_once(JPATH_LIBRARIES.DS.'joomla'.DS.'cache'.DS.'handler'.DS.'page.php');

// Extend JCache Page class
class JA_JCachePage extends JCachePage {
	
	/**
	 * Get the cached page data
	 *
	 * @access	public
	 * @param	string	$id		The cache data id
	 * @param	string	$group	The cache data group
	 * @return	boolean	True if the cache is hit (false else)
	 * @since	1.5
	 */
	function get( $id=false, $group='page', $params )
	{
		// Initialize variables
		$data = false;

		// If an id is not given generate it from the request
		if ($id == false) {
			$id = $this->_makeId($params);
		}

		// If the etag matches the page id ... sent a no change header and exit : utilize browser cache
		if ( !headers_sent() && isset($_SERVER['HTTP_IF_NONE_MATCH']) ){
			$etag = stripslashes($_SERVER['HTTP_IF_NONE_MATCH']);
			if( $etag == $id) {
				$browserCache = isset($this->_options['browsercache']) ? $this->_options['browsercache'] : false;
				if ($browserCache) {
					$this->_noChange();
				}
			}
		}

		// We got a cache hit... set the etag header and echo the page data
		$data = parent::get($id, $group);
		if ($data !== false) {
			$this->_setEtag($id);
			return $data;
		}

		// Set id and group placeholders
		$this->_id		= $id;
		$this->_group	= $group;
		return false;
	}

	/**
	 * Generate a page cache id
	 * @todo	Discuss whether this should be coupled to a data hash or a request hash ... perhaps hashed with a serialized request
	 *
	 * @access	private
	 * @return	string	MD5 Hash : page cache id
	 * @since	1.5
	 */
	function _makeId($params)
	{
		$string = JRequest::getURI();
		
		if($params->get("usebrowser", "1") == "1")
			$string .= $_SERVER['HTTP_USER_AGENT'];
		
		if($params->get("usecookie", "1") == "1"){
			foreach($_COOKIE as $k=>$v)
				$string .= $k.$v;
		}
		
		if($params->get("userequest", "1") == "1"){
			foreach($_REQUEST as $k=>$v)
				$string .= $k.$v;
		}
		
		$string = str_replace(array(" ", "/"), "", $string);
		
		return md5($string);
	}

}

// Extend JCache
class JA_JCache extends JCache{
	
	// Constructor
	function __construct($options){
		parent::__construct($options);
	}
	
	/**
	 * Returns a reference to a cache adapter object, always creating it
	 *
	 * @static
	 * @param	string	$type	The cache object type to instantiate
	 * @return	object	A JCache object
	 * @since	1.5
	 */
	function &getInstance($type = 'output', $options = array())
	{
		$type = strtolower(preg_replace('/[^A-Z0-9_\.-]/i', '', $type));

		$class = 'JA_JCache'.ucfirst($type);

		$instance = new $class($options);

		return $instance;
	}
}

?>